//////////////////////////////////////////////////////////////////////////////
//	Copyright  2006 General Standards Corporation
/////////////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include "GscApi.h"

//--------------------------------------------------------
//	GscSio4DisplayErrorMessage:
//
//  This routine calls the API to get the text that
//	corresponds to a numeric error code. The routine is
//	guaranteed to return a valid string and the string
//	will always be less than 80 characters long.
//
//	errorCode = error code # returned by API
//--------------------------------------------------------
void GscSio4DisplayErrorMessage( int errorCode)
{
	// Buffer to hold the error message
	char errorMessage[80];

	// Call the API to interpret the message
	GscSio4GetErrorString( errorCode, errorMessage);

	// Display the error
	printf("\n\n\tError Code: %d, %s", errorCode, errorMessage);
	printf("\n\tPress any key to continue\n\n");

	// Wait for a key press
	getch();
}	//	end GscSio4DisplayErrorMessage()



//
//	main():
//
int main(void)
{
	int		libVersion, driverVersion, fpgaVersion, status, boardCount, i;
	char	kbchar;
	GSC_DEVICES_STRUCT results;


	status = GscSio4FindBoards( &boardCount, &results);
	if (status) GscSio4DisplayErrorMessage( status );
	else
	{
		printf("\n ----------------------------------------------");
		printf("\n Boards Found:\t\t%d", boardCount);
//		printf("\n Bus Number:\t%d", results.busNumber);
//		printf("\n Slot Number:\t\t%d", results.slotNumber);
//		printf("\n Vendor ID:\t0x%04X", results.vendorId);
//		printf("\n Device ID:\t\t0x%04X", results.deviceId);
//		printf("\n Vendor ID:\t%s", results.serialNumber);
		printf("\n ----------------------------------------------");
	}


	for(i = 1; i < (boardCount + 1); i++)
	{
		//
		// open board number iboardNumber
		//
		status = GscSio4Open(i);
		if (status) GscSio4DisplayErrorMessage( status );

		//
		//	Display Versions:
		//
		status = GscSio4GetVersions(i, &libVersion, &driverVersion, &fpgaVersion);
		if(status)
			GscSio4DisplayErrorMessage(status);
		else
		{
			printf("\n ----------------------------------------------");
			printf("\n Board Number:\t\t%d", i);
			printf("\n API Version:\t\t0x%08lX", libVersion);
			printf("\n Driver Version:\t0x%08lX", driverVersion);
			printf("\n Firmware Version:\t0x%08lX", fpgaVersion);
			printf("\n ----------------------------------------------");
		}

		//
		//	close handle to SIO4 Board
		//
		status = GscSio4Close(i);
		if (status) GscSio4DisplayErrorMessage(status);
		else printf("\n Board %d closed", i);
	}


//	printf("\n");
	return;

	printf("\n DEBUG");

}	//	end main()